/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "common.h"
#include <project.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include "bel.h"
#include "ans.h"
#include "adc.h"
#include "rtc.c"
#include "SDCard_FS.h"
#include "sd.h"
#include "SD.h"
#include <ADC_SAR_SEQ.h>


uint32 dataReady ;
 int16 result[ADC_SAR_SEQ_TOTAL_CHANNELS_NUM];
 uint32 timer_delay ;

int UART_PutCRLF();
  int  UART_PutString();

int main()
{
//Declaration
int main1();
int main2();
int main3();
int main4();

//Calling
    main1();
    main2();
    main3();
    main4();

    return 0;
}
int main1()
{
    int16 res = 0;
    int32 temperature;
    char  uartLine[250];
    int16 ADCCountsCorrected;

    /* Initialize the UART */
    UART_Start();
    UART_UartPutCRLF(16);
    UART_UartPutCRLF(16);
    UART_UartPutString("Starting temperature measurement...");
    UART_UartPutCRLF(16);
    
    PWM_Start();
    PWM_TriggerCommand(PWM_MASK, PWM_CMD_START);

    /* Init and start sequencing SAR ADC */
    ADC_SAR_SEQ_Start();
    ADC_SAR_SEQ_StartConvert();
    /* Enable interrupt and set interrupt handler to local routine */
    ADC_SAR_SEQ_IRQ_StartEx(ADC_SAR_SEQ_ISR_LOC);
    
    /* Init interrupt from timer to measure the temperature rarely */
    ISR_TIMER_StartEx(ISR_TIMER_LOC);

    CyGlobalIntEnable;

    for(;;)
    {
        /* When conversion of sequencing channels has completed */
        if((dataReady & ADC_SAR_SEQ_EOS_MASK) != 0u)
        {
            /* Get voltage, measured by ADC */
            dataReady &= ~ADC_SAR_SEQ_EOS_MASK;
            res = ADC_SAR_SEQ_CountsTo_mVolts(CH0_N, result[CH0_N]);
        }    
        
        /* When conversion of the injection channel has completed */
        if((dataReady & ADC_SAR_SEQ_INJ_EOC_MASK) != 0u)
        {
            dataReady &= ~ADC_SAR_SEQ_INJ_EOC_MASK;

            /******************************************************************************
            * Adjust data from ADC with respect to Vref value.
            * This adjustment is to be done if Vref is set to any other than
            * internal 1.024V.
            * For more detailed description see Functional Description section
            * of DieTemp P4 datasheet.
            *******************************************************************************/
            ADCCountsCorrected = result[TEMP_CH]*((int16)((float)ADC_VREF_VALUE_V/1.024));
            
            temperature = DieTemp_CountsTo_Celsius(ADCCountsCorrected);

            /* Print temperature value to UART */
            sprintf(
                    uartLine, "Temperature value: %dC",
                    (int16) temperature
                    );
            
            UART_UartPutString(uartLine);
            UART_UartPutCRLF(16);
            
            /* Print voltage value to UART */
            sprintf(
                uartLine, "ADC measured voltage: %dmV",
                (uint16) res
                );
            
            UART_UartPutString(uartLine);
            UART_UartPutCRLF(16);
        }
    }
}
int main2()
{
    char timeBuffer[16u];
    char dateBuffer[16u];

    uint32 time;
    uint32 date;

    /* Enable WCO */
    CySysClkWcoStart();
    
    /* Enable global interrupts */
    CyGlobalIntEnable;

    /* Alarm structure initialization */
    alarmTimeDate.time = ALARM_TIME_HR_MIN_SEC;
    alarmTimeDate.date = ALARM_DATE_MONTH_DAY_YEAR;
    
    /* Prepare COUNTER0 to use it by CySysTimerDelay function in
     * "INTERRUPT" mode: disable "clear on match" functionality, configure
     * COUNTER0 to generate interrupts on match.
     */
    CySysWdtSetClearOnMatch(CY_SYS_WDT_COUNTER0, 0u);
    CySysWdtSetMode(CY_SYS_WDT_COUNTER0, CY_SYS_WDT_MODE_INT);
    
    /* Enable WDT COUNTER0 */
    CySysWdtEnable(CY_SYS_WDT_COUNTER0_MASK);
    
    /* Disable servicing interrupts from WDT_COUNTER0 to prevent
       trigger callback before the CySysTimerDelay() function. */
    CySysWdtDisableCounterIsr(CY_SYS_WDT_COUNTER0);
    
    /* Register EnableRtcOperation() by the COUNTER0. */
    CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER0, EnableRtcOperation);
    
    /* Initiate run the EnableRtcOperation() callback in WCO_STARTUP_DELAY_CYCLES interval. */
    CySysTimerDelay(CY_SYS_WDT_COUNTER0, CY_SYS_TIMER_INTERRUPT, WCO_STARTUP_DELAY_CYCLES);
    
    /* Start RTC component */
    RTC_Start();
    
    /* Set Date and Time */
    RTC_SetDateAndTime(TIME_HR_MIN_SEC,DATE_MONTH_DAY_YEAR);

    /* Ignore second mask to call alarm */
    RTC_SetAlarmMask((uint32)~RTC_ALARM_SEC_MASK);
    
    /* Set Alarm Date and Time */
    RTC_SetAlarmDateAndTime(&alarmTimeDate);

    /* Set RTC time update period */
    RTC_SetPeriod(1u, TICK_EACH_1_HZ);

    /* Set function AlarmIsrHandler to be called when alarm triggers */
    RTC_SetAlarmHandler(AlarmIsrHandler);
    
    while(1)
    {

        /* Get Date and Time from RTC */
        time = RTC_GetTime();
        date = RTC_GetDate();

        /* Print Date and Time to UART */
        sprintf(timeBuffer, "%02lu:%02lu:%02lu", RTC_GetHours(time), RTC_GetMinutes(time), RTC_GetSecond(time));
        sprintf(dateBuffer, "%02lu/%02lu/%02lu", RTC_GetMonth(date), RTC_GetDay(date), RTC_GetYear(date));

        UART_PutString(timeBuffer);
        UART_PutString(" | ");
        UART_PutString(dateBuffer);
        UART_PutString(" | ");

        if (alarmFlag == 1u)
        {
            UART_PutString("  Alarm ");
            alarmFlag  = 0u;
        }
        else
        {
            UART_PutString("No alarm");
        }

        UART_PutString("\r");

        /* Switch to Sleep Mode */
        CySysPmDeepSleep();
    }
}

int main3()
{
    char8 command;
    uint8 config[2u];
    uint8 charVal[2u];
    CYBLE_API_RESULT_T apiResult;

    CyGlobalIntEnable;

    /* Start CYBLE component and register generic event handler */
    CyBle_Start(AppCallBack);

    /* Register the event handler for ANS specific events */
    CyBle_AnsRegisterAttrCallback(AnsServiceAppEventHandler);

    UART_Start();

    SW2_Interrupt_StartEx(&ButtonPressInt);

    while(1)
    {
        /* CyBle_ProcessEvents() allows BLE stack to process pending events */
        CyBle_ProcessEvents();

        /* To achieve low power in the device */
        LowPowerImplementation();

        if((command = UART_UartGetChar()) != 0u)
        {
            switch(command)
            {
            case 'c':

                DBG_PRINTF("\r\n");
                DBG_PRINTF("Enter category to turn off corresponding LED (\'e\' - \"Email\", \'m\' - \"Missed call\", \r\n");
                DBG_PRINTF("\'s\' - \"SMS/MMS\"):\n");
                do
                {
                    command = UART_UartGetChar();
                }
                while(command == 0u);

                if((command == 'e') || (command == 'm') || (command == 's'))
                {
                    DBG_PRINTF("%c\r\n",command);
                    if(command == 'e')
                    {
                        DBG_PRINTF("\"Email\" alert LED is cleared.\r\n");
                        Adv_Green_LED_Write(LED_OFF);
                    }
                    else if(command == 'm')
                    {
                        DBG_PRINTF("\"Missed call\" alert LED is cleared.\r\n");
                        Disc_Red_LED_Write(LED_OFF);
                    }
                    else
                    {
                        DBG_PRINTF("\"SMS/MMS\" alert LED is cleared.\r\n");
                        Sms_Blue_LED_Write(LED_OFF);
                    }
                }
                else
                {
                    DBG_PRINTF(" Wrong digit \r\n");
                }
                break;

            case 'd':                   /* Disconnect */
                apiResult = CyBle_GapDisconnect(cyBle_connHandle.bdHandle);

                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("Disconnect Device routine Error: %x.\r\n", apiResult);
                }
                else
                {
                    DBG_PRINTF("Disconnect Device routine Success.\r\n");
                }
                break;

            case 'e':
                charVal[ANCP_COMMAND_ID_INDEX] = CYBLE_ANS_IMM_NEW_ALERT_NTF;
                charVal[ANCP_CATEGORY_ID_INDEX] = CYBLE_ANS_CAT_ID_EMAIL;

                apiResult =
                    CyBle_AnscSetCharacteristicValue(cyBle_connHandle, CYBLE_ANS_ALERT_NTF_CONTROL_POINT, 2u, charVal);

                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Error: %d \r\n",
                        apiResult);
                }
                else
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Success \r\n");
                }
                break;

            case 'm':
                charVal[ANCP_COMMAND_ID_INDEX] = CYBLE_ANS_IMM_NEW_ALERT_NTF;
                charVal[ANCP_CATEGORY_ID_INDEX] = CYBLE_ANS_CAT_ID_MISSED_CALL;

                apiResult =
                    CyBle_AnscSetCharacteristicValue(cyBle_connHandle, CYBLE_ANS_ALERT_NTF_CONTROL_POINT, 2u, charVal);

                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Error: %d \r\n",
                        apiResult);
                }
                else
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Success \r\n");
                }
                break;

            case 's':
                charVal[ANCP_COMMAND_ID_INDEX] = CYBLE_ANS_IMM_NEW_ALERT_NTF;
                charVal[ANCP_CATEGORY_ID_INDEX] = CYBLE_ANS_CAT_ID_SMS_MMS;

                apiResult =
                    CyBle_AnscSetCharacteristicValue(cyBle_connHandle, CYBLE_ANS_ALERT_NTF_CONTROL_POINT, 2u, charVal);

                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Error: %d \r\n",
                        apiResult);
                }
                else
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Success \r\n");
                }
                break;

            case 'r':

                apiResult = CyBle_AnscGetCharacteristicValue(cyBle_connHandle, CYBLE_ANS_SUPPORTED_NEW_ALERT_CAT);

                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("CyBle_AnscGetCharacteristicValue(CYBLE_ANS_SUPPORTED_NEW_ALERT_CAT) routine Error: %d \r\n",
                        apiResult);
                }
                else
                {
                    DBG_PRINTF("CyBle_AnscGetCharacteristicValue(CYBLE_ANS_SUPPORTED_NEW_ALERT_CAT) routine Success \r\n");
                }
                break;

            case 't':
                charVal[ANCP_COMMAND_ID_INDEX] = CYBLE_ANS_EN_NEW_ALERT_NTF;
                charVal[ANCP_CATEGORY_ID_INDEX] = CYBLE_ANS_CAT_ID_ALL;

                apiResult =
                    CyBle_AnscSetCharacteristicValue(cyBle_connHandle, CYBLE_ANS_ALERT_NTF_CONTROL_POINT, 2u, charVal);

                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Error: %d \r\n",
                        apiResult);
                }
                else
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Success \r\n");
                }
                break;

            case 'o':
                charVal[ANCP_COMMAND_ID_INDEX] = CYBLE_ANS_DIS_NEW_ALERT_NTF;
                charVal[ANCP_CATEGORY_ID_INDEX] = CYBLE_ANS_CAT_ID_ALL;

                apiResult =
                    CyBle_AnscSetCharacteristicValue(cyBle_connHandle, CYBLE_ANS_ALERT_NTF_CONTROL_POINT, 2u, charVal);

                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Error: %d \r\n",
                        apiResult);
                }
                else
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicValue(CYBLE_ANS_ALERT_NTF_CONTROL_POINT) routine Success \r\n");
                }
                break;

            case '0':     /* Set Notification enable bit in Client Characteristic Configuration
                          * Descriptor of New Alert Characteristic.
                          */
                config[0u] = 0x01u;
                config[1u] = 0x00u;

                apiResult = CyBle_AnscSetCharacteristicDescriptor(cyBle_connHandle,
                                                     CYBLE_ANS_NEW_ALERT,
                                                     CYBLE_ANS_CCCD,
                                                     CYBLE_CCCD_LEN,
                                                     config);
                DBG_PRINTF("\r\n");
                if(apiResult != CYBLE_ERROR_OK)
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicDescriptor routine Error: %d \r\n", apiResult);
                }
                else
                {
                    DBG_PRINTF("CyBle_AnscSetCharacteristicDescriptor routine Success \r\n");
                }
                break;

            case '1':     /* Set Notification enable bit in Client Characteristic Configuration
                          * Descriptor of New Alert Characteristic.
                          */

                    config[0u] = 0x00u;
                    config[1u] = 0x00u;

                    apiResult = CyBle_AnscSetCharacteristicDescriptor(cyBle_connHandle,
                                                         CYBLE_ANS_NEW_ALERT,
                                                         CYBLE_ANS_CCCD,
                                                         CYBLE_CCCD_LEN,
                                                         config);
                    DBG_PRINTF("\r\n");
                    if(apiResult != CYBLE_ERROR_OK)
                    {
                        DBG_PRINTF("CyBle_AnscSetCharacteristicDescriptor routine Error: %d \r\n", apiResult);
                    }
                    else
                    {
                        DBG_PRINTF("CyBle_AnscSetCharacteristicDescriptor routine Success \r\n");
                    }
                break;

            case 'i':  /* Information about available commands */
                DBG_PRINTF("\r\n");
                DBG_PRINTF("Available commands:\r\n");
                DBG_PRINTF(" \'p\' - Command to enter 6 digit passkey.\r\n");
                DBG_PRINTF(" \'b\' - Initiate bonding procedure with peer device.\r\n");
                DBG_PRINTF(" \'d\' - Send disconnect request to peer device.\r\n");
                DBG_PRINTF(" \'c\' - Turn off LED of New Alert Category that was notified previously. Alert category is\r\n");
                DBG_PRINTF("     specified by the following commands: \'e\' - \"Email\", \'m\' - \"Missed call\", \r\n");
                DBG_PRINTF("     \'s\' - \"SMS/MMS\".\r\n");
                DBG_PRINTF(" \'e\' - Send request with immediate notification command for New Alert \r\n");
                DBG_PRINTF("     Characteristic with Category ID set to \"Email\".\r\n");
                DBG_PRINTF(" \'m\' - Send request with immediate notification command for New Alert \r\n");
                DBG_PRINTF("     Characteristic with Category ID set to \"Missed Call\".\r\n");
                DBG_PRINTF(" \'s\' - Send request with immediate notification command for New Alert \r\n");
                DBG_PRINTF("     Characteristic with Category ID set to \"SMS/MMS\".\r\n");
                DBG_PRINTF(" \'r\' - Read Supported New Alert Category Characteristic. This command required\r\n");
                DBG_PRINTF("     for Client to configure local supported categories setting prior\r\n");
                DBG_PRINTF("     sending notification request to the Server.\r\n");
                DBG_PRINTF(" \'t\' - Send \"Enable New Alert Notification\" command to Alert Notification Control\r\n");
                DBG_PRINTF("     Point Characteristic. Category ID is set to \"All categories\".\r\n");
                DBG_PRINTF(" \'o\' - Send \"Disable New Alert Notification\" command to Alert Notification Control\r\n");
                DBG_PRINTF("     Point Characteristic. Category ID is set to \"All categories\".\r\n");
                DBG_PRINTF(" \'0\' - Enable notifications for New Alert Characteristic.\r\n");
                DBG_PRINTF(" \'1\' - Disable notifications for New Alert Characteristic.\r\n");
                break;
            }
        }
  if(BUTTON_IS_PRESSED == buttonState)
        {
            /* Start advertisement */
            if(CYBLE_ERROR_OK == CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST))
            {
                DBG_PRINTF("Device is entered Limited Discovery mode \r\n");
            }

            /* Clear button state */
            buttonState = BUTTON_IS_NOT_PRESSED;
        }

        HandleLeds();

    }
}
int main4()
{
    char   cardInfo;							// Card information  
    char   fp;									// File Pointer  
    uint8  cnt;									// Card inserted state variables  
	uint8  load = 2;							// Card initialization variable
	char   data_r;								// Data read from Card
	
	CyGlobalIntEnable;							// Enable all global interrupts
	
	// Setup and initialize the SD Card
	do
	{
		SDCard_Start();							// Initialize SPI Bus for communication
		SDCard_Select(SDCard_ENABLE); 			// Select card 
			
		cardInfo = 0;  
		cnt = 0;
	    while ( ! cardInfo )          			// Wait for card to communicate  
	    {  
		   cnt++;
		   if(cnt == 0xFF) {cnt = 0;}
	       cardInfo = SDCard_InitCard();
	    }  
			
		load = load - 1;
	}while(load > 0);							// Stay in the loop till the card is initialized.
	
	fcnt = SDCard_GetFileCount();				// Get number of files on Card
	
	// Loop through all the existing files
	// in the SD Card, one by one
	// or skip is count = 0
	for (cnt = 0; cnt < fcnt; cnt++)
	{
		fnam = SDCard_GetFilename(cnt);		// Get the filename of the file with index value in "cnt"
	}
	
	// *****************************************
	// 1. Write File
	// *****************************************
    static uchar file_name[] = "file1.txt";
	fp = SDCard_fopen(file_name, "w");		// Open a file with write mode access. If the file is not present, a new file is created.
	SDCard_fputcs("This is my 1st file.", fp);	// Write a constant string into the file
	SDCard_fclose(fp);           				// Close file
	fp = SDCard_fopen("file_tmp.txt", "w");		// Open a file with write mode access. If the file is not present, a new file is created.
	SDCard_fputcs("This is a temp file.", fp);	// Write a constant string into the file
	SDCard_fclose(fp);           				// Close file
	
	// *****************************************
	// 2. Append File
	// *****************************************
	fp = SDCard_fopen("file2.txt", "w");      	// Open a file with write mode access. If the file is not present, a new file is created.
	SDCard_fputcs("This is my 2nd file.", fp);	// Write a constant string into the file
	SDCard_fclose(fp);           				// Close file
	fp = SDCard_fopen("file2.txt", "a");		// Open the file with append mode access.
	SDCard_fputcs("I appended this text.", fp);	// Write a constant string into the file
	SDCard_fclose(fp);           				// Close file
	
	// *****************************************
	// 3. Read Read
	// *****************************************
	fp = SDCard_fopen("file2.txt", "r");		// Open a file with readonly access.
	siz  = SDCard_GetFileSize(fp);				// Get the file size.
	SDCard_fseek(fp, 0);						// Move to the offset-0, which is the beginning of file
	while(!SDCard_feof(fp))						// Loop till end of file
	{
		data_r = SDCard_fgetc(fp);				// Read the character pointed by fp
	}
	SDCard_fclose(fp);           				// Close file
	
	// *****************************************
	// 4. Rename File
	// *****************************************
	SDCard_Rename("file1.txt", "file_ren.txt");	// Rename file1.txt to file_ren.txt
	
	// *****************************************
	// 5. Copy File
	// *****************************************
	SDCard_Copy("file_tmp.txt", "file_cpy.txt");// Copy the contents of file_tmp.txt to file_cpy.txt
	
	// *****************************************
	// 6. Delete File
	// *****************************************
	SDCard_Remove("file_tmp.txt");				// Delete file_tmp.txt

	SDCard_Select(SDCard_DISABLE);         		// Deselect card  
	SDCard_Stop();								// Stop the communication interface
	
	while(1);									// The End
}

/* [] END OF FILE */


